<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\CashierSale;
use Illuminate\Http\Request;
use App\Models\Cashier;
use App\Models\DrivewaySheet;
use App\Models\FinancialCategory;
use App\Models\SiteRegister;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;
use Gate;

class CashierSaleController extends Controller
{
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->branch_id = session()->get('branch_id');
            return $next($request);
        });

    }
    public $driveway_sheet_approval = null;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        abort_if(Gate::denies('cashier_sale_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $date =  $request->date;
       if ($request->ajax()) {
            $start =  date('Y-m-d', strtotime(strtr($request->min, '/', '-')));
            $end = date('Y-m-d', strtotime(strtr($request->max, '/', '-')));
            $query = CashierSale::query()->where('branch_id',$this->branch_id);
            $dw_sheet = DrivewaySheet::query()->where('branch_id',$this->branch_id);
            if($request->date != null ){
                $query = $query->whereDate('date',$date);
                $this->driveway_sheet_approval = $dw_sheet->whereDate('date',$date);
            }
            if($request->min != null || $request->max != null ){
                $query = $query->whereDate('date','>=',date('Y-m-d',strtotime($start)))->whereDate('date','<=',date('Y-m-d',strtotime($end)));
            }
            $table = DataTables::of($query);
            $table->addIndexColumn();

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('date',function($row){
                return $row->date ? date('d/m/Y',strtotime($row->date)):'';
            });

            $table->editColumn('sub_category_id',function($row){
                return $row->financialcategory ? $row->financialcategory->title : '';
            });

            $table->editColumn('cashier_id',function($row){
                return $row->cashier ? $row->cashier->name : '';
            });

            $table->editColumn('actions', function ($row) {
                $dw_sheet_first = $this->driveway_sheet_approval != null ? $this->driveway_sheet_approval->first() : DrivewaySheet::whereDate('date',$row->date)->first();
                $is_approve = 0;
                if ($dw_sheet_first != null) {
                    $is_approve = $dw_sheet_first->is_approved;
                }
                $viewGate = 'cashier_sale_show';
                $is_approve == 0 ? $editGate = 'cashier_sale_edit' : $editGate = '';
                $is_approve == 0 ? $deleteGate = 'cashier_sale_delete' : $deleteGate = '';
                $crudRoutePart = 'cashier-sales';

                return view('partials.datatablesActions', compact(
                'viewGate',
                'editGate',
                'deleteGate',
                'crudRoutePart',
                'row'
            ));
            });

            $table->rawColumns(['actions', 'placeholder']);
            return $table->make(true);
        }
        return view('admin.cashiersale.index',compact('date'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
        abort_if(Gate::denies('cashier_sale_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $date =  $request->date;
        $subCategory = FinancialCategory::where('status','1')->where('header_id','5')->pluck('title','id')->prepend(trans('global.pleaseSelect'),'');
        $cashiers = Cashier::where('branch_id',$this->branch_id)->where('status',1)->where('type','cashier')->get()->pluck('name','id')->prepend(trans('global.pleaseSelect'),'');
        return view('admin.cashiersale.create',compact('subCategory','cashiers','date'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        abort_if(Gate::denies('cashier_sale_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $request->validate([
            'date' => 'required',
            'sub_category.*' => 'required|integer',
            'amount.*' => 'required|numeric',
            'cashier_id.*' => 'required|integer',
            'detail.*' => 'nullable|string',
        ],[
            'sub_category.*.required' => 'The sub-category field is required.',
            'amount.*.required' => 'The amount field is required.',
            'amount.*.numeric' => 'The amount must be a number.',
        ]);

        if ($request->ajax()) {
            foreach ($request->sub_category as $key => $value) {
                $req_date = strtr($request->date,'/','-');
                $date = date('Y-m-d',strtotime($req_date));
                CashierSale::create([
                    'date' => $date,
                    'sub_category_id' => $request->sub_category[$key],
                    'amount' => $request->amount[$key],
                    'cashier_id' => $request->cashier_id[$key],
                    'detail' => $request->detail[$key],
                    'branch_id' => $this->branch_id,
                ]);
            }
        }
        return response()->json(['success'=>true,'message'=>'Cashier Sale added successfully!','url'=> url('admin/cashier-sales?date='.$date)]);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\CashierSale  $cashierSale
     * @return \Illuminate\Http\Response
     */
    public function show(CashierSale $cashierSale)
    {
        abort_if(Gate::denies('cashier_sale_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

       return view('admin.cashiersale.show',compact('cashierSale'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\CashierSale  $cashierSale
     * @return \Illuminate\Http\Response
     */
    public function edit(CashierSale $cashierSale)
    {
        abort_if(Gate::denies('cashier_sale_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $driveway_sheet = DrivewaySheet::query()->where('branch_id',$this->branch_id)->whereDate('date',$cashierSale->date);
        if ($driveway_sheet != null) {
            if($driveway_sheet->first()->is_approved)
            {
                toastr()->error('Cashier sale can\'t be edit!');
                return redirect()->route('admin.driveway-sheets.index');
            }
        }

       $subCategory = FinancialCategory::where('status','1')->where('header_id','5')->pluck('title','id')->prepend(trans('global.pleaseSelect'),'');
        $cashiers = Cashier::where('branch_id',$this->branch_id)->where('status',1)->where('type','cashier')->get()->pluck('name','id')->prepend(trans('global.pleaseSelect'),'');
        return view('admin.cashiersale.edit',compact('cashierSale','subCategory','cashiers'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\CashierSale  $cashierSale
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, CashierSale $cashierSale)
    {
        abort_if(Gate::denies('cashier_sale_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $driveway_sheet = DrivewaySheet::query()->where('branch_id',$this->branch_id)->whereDate('date',$cashierSale->date);
        if ($driveway_sheet != null) {
            if($driveway_sheet->first()->is_approved)
            {
                toastr()->error('Cashier sale can\'t be edit!');
                return redirect()->route('admin.driveway-sheets.index');
            }
        }

        $request->validate([
            'date' => 'required',
            'sub_category.*' => 'required|integer',
            'amount.*' => 'required|numeric',
            'cashier_id.*' => 'nullable|integer',
            'detail.*' => 'nullable|string',
        ]);
        $req_date = strtr($request->date,'/','-');
        $date = date('Y-m-d',strtotime($req_date));

        $cashierSale->update([
            'date' => $date,
            'sub_category_id' => $request->sub_category,
            'amount' => $request->amount,
            'cashier_id' => $request->cashier_id,
            'detail' => $request->detail,
            'branch_id' => $this->branch_id,
        ]);
        toastr()->info('Cashier Sale has been updated successfully!');
        return redirect('admin/cashier-sales?date='.$date);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\CashierSale  $cashierSale
     * @return \Illuminate\Http\Response
     */
    public function destroy(CashierSale $cashierSale)
    {
        abort_if(Gate::denies('cashier_sale_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $driveway_sheet = DrivewaySheet::query()->where('branch_id',$this->branch_id)->whereDate('date',$cashierSale->date);
        if ($driveway_sheet != null) {
            if($driveway_sheet->first()->is_approved)
            {
                toastr()->error('Cashier sale can\'t be delete!');
                return redirect()->route('admin.driveway-sheets.index');
            }
        }

        $cashierSale->forceDelete();
        toastr()->error('Cashier Sale has been deleted!');
        return redirect('admin/cashier-sales?date='.$cashierSale->date);
    }

    public function massDestroy(Request $request)
    {
        abort_if(Gate::denies('cashier_sale_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $request->validate([
            'ids'   => 'required|array',
            'ids.*' => 'exists:cashier_sales,id',
        ]);

        foreach($request->ids as $id){
            $cashier_sale = CashierSale::find($id);
            $this->destroy($cashier_sale);
        }
        // toastr()->error('Deposit has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }
}
