<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyDepositOrSaleRequest;
use App\Http\Requests\StoreDepositOrSaleRequest;
use App\Http\Requests\UpdateDepositOrSaleRequest;
use App\Models\DepositOrSale;
use App\Models\Header;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;
use Gate;

class DepositOrSaleController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        abort_if(Gate::denies('deposit_or_sale_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        // dd(SheelCard::FUEL_TYPE_SELECT['V-Power']['price']);

        if ($request->ajax()) {
            $query = DepositOrSale::where('deleted_at','=',null)->get();
            $table = DataTables::of($query);

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate = 'deposit_or_sale_show';
                $editGate = 'deposit_or_sale_edit';
                $deleteGate = 'deposit_or_sale_delete';
                $crudRoutePart = 'deposits-sales';

                return view('partials.datatablesActions', compact(
                'viewGate',
                'editGate',
                'deleteGate',
                'crudRoutePart',
                'row'
            ));
            });

            $table->editColumn('id', function ($row) {
                return $row->id ? $row->id : '';
            });
            $table->editColumn('date', function ($row) {
                return $row->date ? $row->date : '';
            });
            $table->editColumn('title', function ($row) {
                return $row->title ? $row->title : '';
            });
            $table->editColumn('amount', function ($row) {
                return $row->amount ? $row->amount : '';
            });
            $table->editColumn('mode', function ($row) {
                return $row->mode ? DepositOrSale::MODE_TYPE_SELECT[$row->mode] : '';
            });
            $table->editColumn('description', function ($row) {
                return $row->description ? $row->description : '';
            });
            $table->rawColumns(['actions', 'placeholder', 'Deposit Or Sale']);

            return $table->make(true);
        }

        return view('admin.depositOrSales.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        abort_if(Gate::denies('deposit_or_sale_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $headers = Header::all();
        // dd($headers);

        return view('admin.depositOrSales.create',compact('headers'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreDepositOrSaleRequest $request)
    {
        DepositOrSale::create($request->all());
        return redirect()->route('admin.deposits-sales.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        abort_if(Gate::denies('deposit_or_sale_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $depositOrSale = DepositOrSale::find($id);
        return view('admin.depositOrSales.show', compact('depositOrSale'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        abort_if(Gate::denies('deposit_or_sale_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $depositOrSale = DepositOrSale::find($id);
        $headers = Header::all();

        return view('admin.depositOrSales.edit', compact(['depositOrSale','headers']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateDepositOrSaleRequest $request, $id)
    {
        $depositOrSale = DepositOrSale::find($id);
        // dd($depositOrSale);
        $depositOrSale->update($request->all());

        return redirect()->route('admin.deposits-sales.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $depositOrSale = DepositOrSale::find($id);
        $depositOrSale->delete();
        return back();
    }

    /**
     * massDestroy for
     * destory multiple
     * resources at a time
     * using IDs
     *
     * @param  mixed $request
     * @return void
     */
    public function massDestroy(MassDestroyDepositOrSaleRequest $request)
    {
        DepositOrSale::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
