<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyHeaderRequest;
use App\Http\Requests\StoreHeaderRequest;
use App\Http\Requests\UpdateHeaderRequest;
use App\Models\Header;
use Illuminate\Http\Request;
use Gate;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class HeaderController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function index(Request $request)
    {
        abort_if(Gate::denies('header_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $query = Header::all();
            $table = DataTables::of($query);
            $table->addIndexColumn();

            $table->addColumn('DT_RowId',function($row){
                return $row->id ? $row->id : '' ;
            });
            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate = 'header_show';
                $editGate = 'header_edit';
                $deleteGate = '';
                if($row->type == 1){
                    $deleteGate = 'header_delete';
                }
                $crudRoutePart = 'headers';

                return view('partials.datatablesActions', compact(
                'viewGate',
                'editGate',
                'deleteGate',
                'crudRoutePart',
                'row'
            ));
            });

            $table->editColumn('station', function ($row) {
                return $row->station ? ucfirst($row->station) : '';
            });

            $table->editColumn('header_name', function ($row) {
                return $row->header_name ? $row->header_name : '';
            });
            $table->editColumn('code', function ($row) {
                return $row->code ? $row->code : '';
            });
            $table->editColumn('category_type', function ($row) {
                return $row->category_type ? ucfirst($row->category_type) : '';
            });
            $table->rawColumns(['actions', 'placeholder', 'header']);

            return $table->make(true);
        }

        return view('admin.depositOrSales.headers.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function create()
    {
        abort_if(Gate::denies('header_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.depositOrSales.headers.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function store(StoreHeaderRequest $request)
    {
        $header = Header::create($request->all());
        $header->code = 'cat'.$header->id;
        $header->save();
        toastr()->success('Financial category is created successfully!');
        return redirect()->route('admin.headers.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function show(Header $header)
    {
        abort_if(Gate::denies('header_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.depositOrSales.headers.show', compact('header'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function edit(Header $header)
    {
        abort_if(Gate::denies('header_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.depositOrSales.headers.edit', compact('header'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function update(UpdateHeaderRequest $request, Header $header)
    {
        // if($header->type == '0'){
        //     toastr()->error('You are not allowed to edit this category!');
        //     return redirect()->route('admin.headers.index');
        // }
        $header->update($request->all());
        $header->code = 'cat'.$header->id;
        $header->save();
        toastr()->info('Financial category has been updated successfully!');
        return redirect()->route('admin.headers.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function destroy(Header $header)
    {
        abort_if(Gate::denies('header_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        if($header->type == '0'){
            toastr()->error('You are not allowed to delete this category!');
            return redirect()->route('admin.headers.index');
        }
        if(isset($header->subcategories) && count($header->subcategories) > 0){
            toastr()->error('It has associated data. Please delete that first!');
            return back();
        }
        $header->forceDelete();
        toastr()->error('Financial category has been deleted!');
        return back();
    }
    public function massDestroy(Request $request)
    {
        abort_if(Gate::denies('header_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $request->validate([
            'ids'   => 'required|array',
        ]);
        foreach($request->ids as $id){
            $header = Header::find($id);
            $this->destroy($header);
        }
        // Header::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
