<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StorePaymentAdviceRequest;
use App\Http\Requests\UpdatePaymentAdviceRequest;
use App\Http\Resources\Admin\PaymentAdviceResource;
use App\Models\PaymentAdvice;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class PaymentAdviceApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('payment_advice_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new PaymentAdviceResource(PaymentAdvice::all());
    }

    public function store(StorePaymentAdviceRequest $request)
    {
        $paymentAdvice = PaymentAdvice::create($request->all());

        return (new PaymentAdviceResource($paymentAdvice))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(PaymentAdvice $paymentAdvice)
    {
        abort_if(Gate::denies('payment_advice_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new PaymentAdviceResource($paymentAdvice);
    }

    public function update(UpdatePaymentAdviceRequest $request, PaymentAdvice $paymentAdvice)
    {
        $paymentAdvice->update($request->all());

        return (new PaymentAdviceResource($paymentAdvice))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(PaymentAdvice $paymentAdvice)
    {
        abort_if(Gate::denies('payment_advice_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $paymentAdvice->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
