<?php

namespace App\Http\Controllers\Api\v1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreSpeedPointRequest;
use App\Http\Requests\UpdateSpeedPointRequest;
use App\Http\Resources\Admin\SpeedPointResource;
use App\Models\SpeedPoint;
use Illuminate\Http\Request;
use Gate;
use Symfony\Component\HttpFoundation\Response;

class SpeedPointApiController extends Controller
{
    /**
     * Get All Speed Point Details
     *
     * @return void
     */
    public function index()
    {
        abort_if(Gate::denies('speed_point_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new SpeedPointResource(SpeedPoint::where('deleted_at','=',null)->get());
    }

    /**
     * store for store
     * a new details of speed point
     *
     * @param  mixed $request
     * @return void
     */
    public function store(StoreSpeedPointRequest $request)
    {
        $speedPoint = SpeedPoint::create($request->all());

        return (new SpeedPointResource($speedPoint))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    /**
     * show
     * for particular
     * details
     *
     * @param  mixed $speedPoint
     * @return void
     */
    public function show(SpeedPoint $speedPoint)
    {
        abort_if(Gate::denies('speed_point_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new SpeedPointResource($speedPoint);
    }

    /**
     * update
     * for update
     * particular details
     *
     * @param  mixed $request
     * @param  mixed $speedPoint
     * @return void
     */
    public function update(UpdateSpeedPointRequest $request, SpeedPoint $speedPoint)
    {
        $speedPoint->update($request->all());

        return (new SpeedPointResource($speedPoint))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    /**
     * destroy
     * for delete
     * particular details
     *
     * @param  mixed $speedPoint
     * @return void
     */
    public function destroy(SpeedPoint $speedPoint)
    {
        abort_if(Gate::denies('speed_point_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $speedPoint->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
