<?php

namespace App\Http\Requests;

use App\Models\CashExpense;
use Gate;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Response;

class StoreCashExpenseRequest extends FormRequest
{
    public function authorize()
    {
        return Gate::allows('cash_expense_create');
    }

    public function rules()
    {
        return [
            'date' => [
                'required',
                // 'date_format:' . config('panel.date_format'),
            ],
            'invoice_no.*' => [
                // 'string',
                'max:20',
                'required',
                'unique:cash_expenses,invoice_no',
                // 'distinct',
            ],
            'suplier.*' => [
                'nullable',
                'integer',
            ],
            'bank_account.*' => [
                'required',
                'integer',
            ],
            'sub_category.*' => [
                'required',
                'integer',
            ],
            'cash_credit.*' => [
                'required',
            ],
            'reference.*' => [
                'nullable',
            ],
            'vat_category.*' => [
                'nullable',
            ],

            'attachment.*' => 'nullable|image|mimes:jpg,jpeg,png,svg',

            'total_amount.*' => [
                'required',
            ],
        ];
    }

    public function messages()
    {
        return [
            'date.*.required' => 'The date field is required.',
            'invoice_no.*.required' => 'The invoice no. field is required.',
            'invoice_no.*.unique' => 'The invoice no. has already taken.',
            'suplier.*.required' => 'The suplier field is required.',
            'bank_account.*.required' => 'The bank account field is required.',
            'sub_category.*.required' => 'The sub category field is required.',
            'cash_credit.*.required' => 'The cash credit field is required.',
            'total_amount.*.required' => 'The total amount field is required.',
            'total_amount.*.numeric' => 'The amount field must be a number.',
        ];
    }
}
