@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.account.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a>
                        </li>
                        <li class="breadcrumb-item"><a
                                href="{{route('admin.accounts.index')}}">{{trans('cruds.account.title') }}</a>
                        </li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.accounts.index') }}" class="btn add-btn"> <i
                            class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.edit') }} {{ trans('cruds.account.title_singular') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.accounts.update", [$account->id]) }}" enctype="multipart/form-data">
                    @method('PUT')
                    @csrf
                    <div class="row">
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="day">{{ trans('cruds.account.fields.date') }}</label>
                                <input type="text" name="date" id="day" class="form-control date {{$errors->has('date')? 'is-invalid':''}}" value="{{ old('date', date('d/m/Y',strtotime($account->date))) }}" step="1" >
                                @if ($errors->first('date'))
                                    <div class="invalid-feedback">
                                        {{$errors->first('date')}}
                                    </div>
                                @endif
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="shift_no">{{ trans('cruds.account.fields.shift_no') }}</label>
                                <select class="form-control {{ $errors->has('shift_no') ? 'is-invalid' : '' }}" type="text" name="shift_no" id="shift_no">
                                @foreach ($shift as $key => $value)
                                    <option value="{{$key}}" {{$account->shift_no == $key ? 'selected':''}}>{{$value}}</option>
                                @endforeach
                                </select>
                                @if($errors->has('shift_no'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('shift_no') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.account.fields.shift_no_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="invoice_no">{{ trans('cruds.account.fields.invoice_no') }}</label>
                                <input class="form-control {{ $errors->has('invoice_no') ? 'is-invalid' : '' }}" type="text" name="invoice_no" id="invoice_no" value="{{ old('invoice_no', $account->invoice_no) }}" required>
                                @if($errors->has('invoice_no'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('invoice_no') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.account.fields.invoice_no_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="company_name">{{ trans('cruds.account.fields.company_name') }}</label>
                                <select class="form-control {{ $errors->has('company_name') ? 'is-invalid' : '' }}" type="text" name="company_name" id="company_name">
                                @foreach ($supplier as $key=>$value)
                                    <option value="{{$key}}" {{$account->company_name == $key? 'selected':''}}>{{$value}}</option>
                                @endforeach
                                </select>
                                @if($errors->has('company_name'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('company_name') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.account.fields.company_name_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label for="amount">{{ trans('cruds.account.fields.amount') }}</label>
                                <input class="form-control {{ $errors->has('amount') ? 'is-invalid' : '' }}" type="number" name="amount" id="amount" value="{{ old('amount', $account->amount) }}" step="0.01">
                                @if($errors->has('amount'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('amount') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.account.fields.amount_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="order_no">{{ trans('cruds.account.fields.order_no') }}</label>
                                <input class="form-control {{ $errors->has('order_no') ? 'is-invalid' : '' }}" type="text" name="order_no" id="order_no" value="{{ old('order_no', $account->order_no) }}" required>
                                @if($errors->has('order_no'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('order_no') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.account.fields.order_no_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label class="required" for="veh_reg_no">{{ trans('cruds.account.fields.veh_reg_no') }}</label>
                                <input class="form-control {{ $errors->has('veh_reg_no') ? 'is-invalid' : '' }}" type="text" name="veh_reg_no" id="veh_reg_no" value="{{ old('veh_reg_no', $account->veh_reg_no) }}" required>
                                @if($errors->has('veh_reg_no'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('veh_reg_no') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.account.fields.veh_reg_no_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label for="fleet_no">{{ trans('cruds.account.fields.fleet_no') }}</label>
                                <input class="form-control {{ $errors->has('fleet_no') ? 'is-invalid' : '' }}" type="text" name="fleet_no" id="fleet_no" value="{{ old('fleet_no', $account->fleet_no) }}">
                                @if($errors->has('fleet_no'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('fleet_no') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.account.fields.fleet_no_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label for="d_name">{{ trans('cruds.account.fields.d_name') }}</label>
                                <input class="form-control {{ $errors->has('d_name') ? 'is-invalid' : '' }}" type="text" name="d_name" id="d_name" value="{{ old('d_name', $account->d_name) }}">
                                @if($errors->has('d_name'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('d_name') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.account.fields.d_name_helper') }}</span>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-6">
                            <div class="form-group">
                                <button class="btn btn-primary" type="submit">
                                    {{ trans('global.save') }}
                                </button>
                            </div>

                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>



@endsection
