@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.cashExpense.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.cash-expenses.index')}}">{{trans('cruds.cashExpense.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.cash-expenses.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.edit') }} {{ trans('cruds.cashExpense.title_singular') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.cash-expenses.update", [$cashExpense->id]) }}" enctype="multipart/form-data">
                    @method('PUT')
                    @csrf
                    <div class="row">
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="date">{{ trans('cruds.cashExpense.fields.date') }}</label>
                                <input class="form-control date {{ $errors->has('date') ? 'is-invalid' : '' }}" type="text" name="date" id="date" value="{{ old('date', date('d/m/Y',strtotime($cashExpense->date))) }}" required>
                                @if($errors->has('date'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('date') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.cashExpense.fields.date_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="invoice_no">{{ trans('cruds.cashExpense.fields.invoice_no') }}</label>
                                <input class="form-control {{ $errors->has('invoice_no') ? 'is-invalid' : '' }}" type="text" name="invoice_no" id="invoice_no" value="{{ old('invoice_no', $cashExpense->invoice_no) }}" required>
                                @if($errors->has('invoice_no'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('invoice_no') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.cashExpense.fields.invoice_no_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="suplier">{{ trans('cruds.cashExpense.fields.suplier') }}</label>
                                <select class="form-control select2 {{ $errors->has('suplier') ? 'is-invalid' : '' }}" name="suplier" id="suplier">
                                    @foreach($supliers as $id => $entry)
                                        <option value="{{ $id }}" {{ (old('suplier') ? old('suplier') : $cashExpense->supplier_id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                                    @endforeach
                                </select>
                                @if($errors->has('suplier'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('suplier') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.cashExpense.fields.suplier_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="sub_category">{{ trans('cruds.cashExpense.fields.header') }}</label>
                                <select class="form-control select2 {{ $errors->has('sub_category') ? 'is-invalid' : '' }}" name="sub_category" id="sub_category" required>
                                    @foreach($headers as $id => $entry)
                                        <option value="{{ $id }}" {{ (old('sub_category') ? old('sub_category') : $cashExpense->financial_category_id?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                                    @endforeach
                                </select>
                                @if($errors->has('sub_category'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('sub_category') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.cashExpense.fields.suplier_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="bank_account">{{ trans('cruds.cashExpense.fields.bank_ac') }}</label>
                                <select class="form-control select2 {{ $errors->has('bank_account') ? 'is-invalid' : '' }}" name="bank_account" id="bank_account">
                                    @foreach($bankAccount as $id => $entry)
                                        <option value="{{ $id }}" {{ (old('bank_account') ? old('bank_account') : $cashExpense->bank_account_id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                                    @endforeach
                                </select>
                                @if($errors->has('bank_account'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('bank_account') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.cashExpense.fields.suplier_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="vat_category">{{ trans('cruds.cashExpense.fields.vat') }}</label>
                                <select class="form-control select2 {{ $errors->has('vat_category') ? 'is-invalid' : '' }}" name="vat_category" id="vat_category">
                                    @foreach($vat as $id => $entry)
                                        <option value="{{ $id }}" {{ (old('vat_category') ? old('vat_category') : $cashExpense->vat->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                                    @endforeach
                                </select>
                                @if($errors->has('vat_category'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('vat_category') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.cashExpense.fields.suplier_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="cash_credit">{{ trans('cruds.cashExpense.fields.cash_credit') }}</label>
                                <select name="cash_credit" class="form-control" id="cash_credit">
                                    <option value="Cash" {{$cashExpense->cash_credit == 'cash' ? 'selected' : ''}}>{{__('Cash')}}</option>
                                    <option value="Credit" {{$cashExpense->cash_credit == 'credit' ? 'selected' : ''}}>{{__('Credit')}}</option>
                                </select>
                                @if($errors->has('cash_credit'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('cash_credit') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.cashExpense.fields.suplier_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="reference">{{ trans('cruds.cashExpense.fields.reference') }}</label>
                                <input class="form-control {{ $errors->has('reference') ? 'is-invalid' : '' }}" type="text" name="reference" id="reference" value="{{ old('reference', $cashExpense->reference) }}">
                                @if($errors->has('reference'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('reference') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.cashExpense.fields.amount_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="amount">{{ trans('cruds.cashExpense.fields.total_amount') }}</label>
                                <input class="form-control {{ $errors->has('amount') ? 'is-invalid' : '' }}" type="number" step="any" name="total_amount" id="amount" value="{{ old('amount', $cashExpense->amount_without_vat) }}" required>
                                @if($errors->has('amount'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('amount') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.cashExpense.fields.amount_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="form-group">
                                <label for="description">{{ trans('cruds.cashExpense.fields.description') }}</label>
                                <textarea class="form-control {{ $errors->has('description') ? 'is-invalid' : '' }} CalculateMe" name="description" id="description">{{ old('description', $cashExpense->description) }}</textarea>
                                @if($errors->has('description'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('description') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.cashExpense.fields.description_helper') }}</span>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="form-group">
                                {{-- <button class="btn btn-info" type="reset">
                                    {{ trans('global.reset') }}
                                </button> --}}
                                <button class="btn btn-primary" type="submit">
                                    {{ trans('global.save') }}
                                </button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>
@endsection
