@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.cashier.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        @if (isset($cashier))
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a>
                        </li>
                        <li class="breadcrumb-item"><a
                                href="{{route('admin.cashier.index')}}">{{trans('cruds.cashier.title')}}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                        @else
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a>
                        </li>
                        <li class="breadcrumb-item active">{{trans('cruds.cashier.title')}}</li>
                        @endif
                    </ul>
                </div>
                @if(isset($cashier))
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.cashier.index') }}" class="btn add-btn"> <i
                            class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
                @else
                {{-- <div class="col-auto float-right ml-auto">
                    <a href="" class="btn add-btn"> <i class="fa fa-plus"></i>{{ trans('global.add')}}
                        {{trans('cruds.cashier.title_singular')}}</a>
                </div> --}}
                @endif
            </div>
        </div>
        @can(['cashier_create','cashier_edit'])
            <div class="card">
                <div class="card-header">
                    @if (isset($cashier))
                    {{ trans('global.edit') }} {{ trans('cruds.cashier.title_singular') }}
                    @else
                    {{ trans('global.add') }} {{ trans('cruds.cashier.title_singular') }}
                    @endif
                    {{-- <span style="float: right;">
                        <a href="#" class="text-danger"><i class="fa fa-close"></i></a>
                    </span> --}}
                </div>
                <div class="card-body">
                    @if (isset($cashier))
                    <form action="{{route('admin.cashier.update',[$cashier->id])}}" method="POST" enctype="multipart/form-data">
                    @method('PUT')
                    @else
                    <form action="{{route('admin.cashier.store')}}" method="post" enctype="multipart/form-data">
                    @endif
                    @csrf
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label for="station">{{ trans('cruds.header.fields.type')}}</label>
                                <select class="form-control {{$errors->has('type') ? 'is-invalid' : ''}}" name="type" id="type" required>
                                    <option value="">Please Select</option>
                                    <option value="cashier">Cahsier</option>
                                    <option value="attendent">Attendent</option>
                                </select>
                                @if($errors->first('type'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('type') }}
                                    </div>
                                @endif
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required"
                                    for="name">{{ trans('cruds.cashier.fields.name') }}</label>
                                <input class="form-control {{ $errors->has('name') ? 'is-invalid' : '' }}"
                                    type="text" name="name" id="name"
                                    value="{{ old('name', isset($cashier)?$cashier->name:'') }}" required>
                                @if($errors->has('name'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('name') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.cashier.fields.name_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required"
                                    for="surname">{{ trans('cruds.cashier.fields.surname') }}</label>
                                <input class="form-control {{ $errors->has('surname') ? 'is-invalid' : '' }}"
                                    type="text" name="surname" id="surname"
                                    value="{{ old('surname', isset($cashier)?$cashier->surname:'') }}">
                                @if($errors->has('surname'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('surname') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.cashier.fields.surname_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4 custom-switch">
                            <div class="form-group">
                                <br>
                                <label class="custom-switch">
                                    <input id="status" type="checkbox"
                                        {{isset($cashier) && $cashier->status == 0 ? '' : 'checked'}} value="{{isset($cashier) ? $cashier->status : '1'}}" name="status"
                                        class="custom-control-input">
                                    <label class="custom-control-label" for="status">
                                        {{ trans('cruds.cashier.fields.status') }}</label>
                                </label>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            @if (isset($cashier))
                            <button class="btn btn-primary" type="submit">{{ trans('global.update') }}</button>
                            @else
                            <button class="btn btn-info" type="reset">{{ trans('global.reset') }}</button>
                            <button class="btn btn-primary" type="submit">{{ trans('global.add') }}</button>
                            @endif
                        </div>
                    </div>
                </div>
                </form>
            </div>
        @endcan

        <div class="card">
            <div class="card-header">
                {{ trans('global.list') }} {{ trans('cruds.cashier.title_singular') }}
            </div>
            <div class="card-body">
                <table class="table table-bordered datatable-cashier">
                    <thead>
                        <tr>
                            <th style="width: 10px;"></th>
                            <th>
                                {{__('ID')}}
                            </th>
                            <th>
                                {{ trans('cruds.cashier.fields.name') }}
                            </th>
                            <th>
                                {{ trans('cruds.header.fields.type') }}
                            </th>
                            <th>
                                {{ trans('cruds.cashier.fields.status') }}
                            </th>
                            <th></th>
                        </tr>
                    </thead>
                    <tbody>
                        @if (count($cashier_list) == 0)
                        <tr>
                            <td colspan="3" style="text-align: center;">
                                <span>Records not found</span>
                            </td>
                        </tr>
                        @else
                        @php
                            $i = 1;
                        @endphp
                        @foreach ($cashier_list as $item)
                        <tr data-entry-id="{{$item->id}}">
                            <td></td>
                            <td>
                                {{$i}}
                            </td>
                            <td>
                                {{$item->name}} {{$item->surname}}
                            </td>
                            <td>
                                {{ucfirst($item->type)}}
                            </td>
                            <td>
                                {!! $item->status == 1 ? '<span class="badge bg-inverse-success">Active</span>' : '<span class="badge bg-inverse-danger">Inactive</span>' !!}
                            </td>
                            <td>
                                <div class="button-list">
                                    @can('cashier_edit')
                                        <a href="{{route('admin.cashier.edit', $item->id)}}" class="btn btn-xs btn-info"><i
                                                class="la la-edit"></i></a>
                                    @endcan
                                    @can('cashier_delete')
                                        <button type="button" class="btn btn-xs btn-danger" data-toggle="modal"
                                            data-target="#deleteModal{{$item->id}}"><i class="la la-trash"></i></button>
                                    @endcan

                                    <!-- Modal -->
                                    <div id="deleteModal{{$item->id}}" class="delete-modal modal fade" role="dialog">
                                        <div class="modal-dialog modal-sm">
                                            <div class="modal-content">
                                                <div class="modal-header">
                                                    <button type="button" class="close"
                                                        data-dismiss="modal">&times;</button>
                                                    <div class="delete-icon"></div>
                                                </div>
                                                <div class="modal-body text-center">
                                                    <h4 class="modal-heading">Are You Sure ?</h4>
                                                    <p>Do you really want to delete these records?<br> This process cannot
                                                        be undone.</p>
                                                </div>
                                                <div class="modal-footer">
                                                    {!! Form::open(['method' => 'DELETE', 'route' =>
                                                    ['admin.cashier.destroy',$item->id]]) !!}
                                                    <button type="reset" class="btn btn-dark"
                                                        data-dismiss="modal">No</button>
                                                    <button type="submit" class="btn btn-danger">Yes</button>
                                                    {!! Form::close() !!}
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </td>
                            @php
                                $i++;
                            @endphp
                        </tr>
                        @endforeach
                        @endif
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>
@endsection
@section('scripts')
    <script>
        $(function () {
            let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
            @can('cashier_delete')
            let deleteButtonTrans = '{{ trans('global.datatables.delete') }}'
            let deleteButton = {
                text: deleteButtonTrans,
                url: "{{ route('admin.cashier.massDestroy') }}",
                className: 'bg-inverse-danger',
                action: function (e, dt, node, config) {
                var ids = $.map(dt.rows({ selected: true }).nodes(), function (entry) {
                    return $(entry).data('entry-id')
                });

                if (ids.length === 0) {
                    alert('{{ trans('global.datatables.zero_selected') }}')

                    return
                }

                if (confirm('{{ trans('global.areYouSure') }}')) {
                    $.ajax({
                    headers: {'x-csrf-token': _token},
                    method: 'POST',
                    url: config.url,
                    data: { ids: ids, _method: 'DELETE' }})
                    .done(function () { location.reload() })
                }
                }
            }
            dtButtons.push(deleteButton)
            @endcan

            $.extend(true, $.fn.dataTable.defaults, {
                orderCellsTop: true,
                order: [[ 1, 'desc' ]],
                pageLength: 100,
            });
            let table = $('.datatable-cashier').DataTable({ buttons: dtButtons })
            $('a[data-toggle="tab"]').on('shown.bs.tab click', function(e){
                $($.fn.dataTable.tables(true)).DataTable()
                    .columns.adjust();
            });
            $('div#sidebar').on('transitionend', function(e) {
                $($.fn.dataTable.tables(true)).DataTable().columns.adjust();
            })

        })
    </script>
@endsection
