@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.account.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.speed-points.index')}}">{{trans('cruds.account.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.add')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.driveway-accounts.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.add') }} {{ trans('cruds.account.title_singular') }}
            </div>
            <div class="card-body">
                <form method="POST" action="{{ route("admin.driveway-accounts.store") }}" id="account_form" enctype="multipart/form-data">
                    @csrf
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label for="date">{{ trans('cruds.account.fields.date')}}</label>
                                <input type="text" name="date" id="date" class="form-control floating datetimepicker {{$errors->has('date')? 'is-invalid' : ''}}" value="{{date('d/m/Y')}}">
                                @if($errors->first('date'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('date') }}
                                    </div>
                                @endif
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <table class="table table-bordered" id="field_container">
                                <tr>
                                    <th>
                                        {{ trans('cruds.account.fields.invoice_no') }}
                                    </th>
                                    <th>
                                        {{ trans('cruds.account.fields.account_name') }}
                                    </th>
                                    <th>
                                        {{ trans('cruds.account.fields.amount') }}
                                    </th>
                                    <th>
                                        {{ trans('cruds.account.fields.remarks') }}
                                    </th>
                                    <th></th>
                                </tr>
                                <tr id="copy_content">
                                    <td>
                                        <div class="form-group small">
                                            <input type="text" class="form-control {{ $errors->has('invoice_no.*') ? 'is-invalid' : ''}}" id="invoice_no" name="invoice_no[0]" value="{{ old('invoice_no[0]') }}">
                                            @if($errors->first('invoice_no.*'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('invoice_no.*') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.account.fields.invoice_no_helper') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <select name="account_name[0]" class="form-control {{$errors->has('account_name.*') ? 'is-invalid' : ''}}" id="account_name">
                                                @foreach ($account_info as $key => $value )
                                                    <option value="{{$key}}">{{$value}}</option>
                                                @endforeach
                                            </select>
                                            @if($errors->first('account_name.*'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('account_name.*') }}
                                                </div>
                                            @endif
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" min="1" step="any" class="form-control {{ $errors->has('amount.*') ? 'is-invalid' : ''}}" id="amount" name="amount[0]" value="{{ old('amount[0]') }}">
                                            @if($errors->first('amount.*'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('amount.*') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.account.fields.amount_helper') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="text" class="form-control {{ $errors->has('remarks.*') ? 'is-invalid' : ''}}" id="remarks" name="remarks[0]" value="{{ old('remarks[0]') }}">
                                            @if($errors->first('remarks.*'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('remarks.*') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.account.fields.invoice_no_helper') }}</span>
                                        </div>
                                    </td>
                                    <td><a href="#" class="btn btn-xs btn-danger d-none" id="remove"><i class="fa fa-trash"></i></a></td>
                                </tr>
                            </table>
                            <div class="row my-3">
                                <div class="col-lg-12 text-center">
                                    <button class="btn btn-block btn-light" id="add_row">Add Row</button>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-lg-12">
                                    <div class="form-group">
                                        <button class="btn btn-info" type="reset">
                                            {{ trans('global.reset') }}
                                        </button>
                                        <button class="btn btn-primary" id="btn_submit" type="submit">
                                            {{ trans('global.save') }}
                                        </button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>
@endsection

@section('scripts')
    <script>
        $(document).ready(function(){
            var max = 15;
           var x=0;

            $('#add_row').click(function (e) {
                e.preventDefault();
                if(x < max)
                {
                    x++;
                    var clone_ele = $('#copy_content').clone();
                    clone_ele.find('#remove').removeClass('d-none');
                    clone_ele.find(':input').each(function(){
                        this.value = '';
                        this.id = this.id + '-' + x;
                        this.name = this.name.replace(/\[[0-9]\]+/, '[' + x + ']');
                    });
                    clone_ele.appendTo('#field_container');
                }
            });


            $('#field_container').on('click','#remove',function (e) {
                e.preventDefault();
                $(this).closest('tr').remove();
            });
            var i = 0;
            $('#account_form').on("submit",function (e) {
                e.preventDefault();
                $("#btn_submit").prop('disabled', true);
               $.ajax({
                   type: this.method,
                   url: this.action,
                   data:new FormData(this),
                   dataType:'JSON',
                   contentType: false,
                   cache: false,
                   processData: false,
                   beforeSend: function(response){
                   },
                   success: function (response) {
                    if (response.success) {
                        $('#error').addClass('d-none');
                        toastr.success(response.message);
                        document.getElementById('account_form').reset();
                        setTimeout(function(){
                            window.location = response.url;
                        },1000);
                    }
                    $("#btn_submit").prop('disabled', false);
                   },
                   error: function(response){
                        $.each(response.responseJSON.errors, function (index, value) {
                            toastr.error(value);
                            $("#btn_submit").prop('disabled', false);
                        });
                        window.scroll(top);
                    }
               });

            });
        });
    </script>
@endsection
