@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.account.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.driveway-accounts.index')}}">{{trans('cruds.account.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.driveway-accounts.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.edit') }} {{ trans('cruds.account.title_singular') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.driveway-accounts.update", [$account->id]) }}" enctype="multipart/form-data">
                    @method('PUT')
                    @csrf
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="date">{{ trans('cruds.account.fields.date') }}</label>
                                <input type="text" name="date" id="date" class="form-control floating datetimepicker {{$errors->has('date') ? 'is-invalid' :''}}" value="{{date('d/m/Y',strtotime($account->date))}}">
                                @if($errors->has('date'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('date') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.account.fields.date_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="invoice_no">{{ trans('cruds.account.fields.invoice_no') }}</label>
                                <input class="form-control {{ $errors->has('invoice_no') ? 'is-invalid' : '' }}" type="text" name="invoice_no" id="invoice_no" value="{{ old('invoice_no', $account->invoice_no) }}" required>
                                @if($errors->has('invoice_no'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('invoice_no') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.account.fields.invoice_no_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required">{{ trans('cruds.account.fields.account_name') }}</label>
                                <select class="form-control {{ $errors->has('account_name') ? 'is-invalid' : '' }}" name="account_name" id="account_name" required>
                                    @foreach($account_info as $key => $label)
                                        <option value="{{ $key }}" {{ old('account_name', $account->account_info_id) == $key ? 'selected' : '' }}>{{ $label }}</option>
                                    @endforeach
                                </select>
                                @if($errors->has('account_name'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('account_name') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.account.fields.account_name_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="amount">{{ trans('cruds.account.fields.amount') }}</label>
                                <input class="form-control {{ $errors->has('amount') ? 'is-invalid' : '' }}" type="text" name="amount" id="amount" value="{{ old('amount',$account->amount)}}" required>
                                @if($errors->has('amount'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('amount') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.account.fields.amount_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label for="remarks">{{ trans('cruds.account.fields.remarks') }}</label>
                                <input type="text" class="form-control {{ $errors->has('remarks') ? 'is-invalid' : '' }}" name="remarks" id="remarks" value= "{{ old('remarks' ,$account->remarks) }}">
                                @if($errors->has('remarks'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('remarks') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.account.fields.remarks_helper') }}</span>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <!-- Save Button -->
                            <div class="form-group">
                                <button class="btn btn-primary" type="submit">
                                    {{ trans('global.save') }}
                                </button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

@endsection
