@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.generalLedger.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.general-ledgers.index')}}">{{trans('cruds.generalLedger.title_singular') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.general-ledgers.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.edit') }} {{ trans('cruds.generalLedger.title') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.general-ledgers.update",[$generalLedger->id]) }}" enctype="multipart/form-data">
                    @method('PUT')
                    @csrf
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="date">{{ trans('cruds.generalLedger.fields.date') }}</label>
                                <input class="form-control floating datetimepicker {{ $errors->has('date') ? 'is-invalid' : '' }}" type="text" name="date"  value="{{ old('date', date('d/m/Y',strtotime($generalLedger->date))) }}" required>
                                @if($errors->has('date'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('date') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.generalLedger.fields.date_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="sub_category">{{ trans('cruds.generalLedger.fields.sub_category') }}</label>
                                <select class="sub_cat form-control {{ $errors->has('sub_category') ? 'is-invalid' : '' }}" name="sub_category" required>
                                @foreach ($sub_category as $key => $value)
                                    <option value="{{$key}}" {{$generalLedger->sub_category_id == $key ? 'selected':''}}>{{$value}}</option>
                                @endforeach
                                </select>
                                @if($errors->has('sub_category'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('sub_category') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.generalLedger.fields.sub_category_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4 cashier-block {{$generalLedger->cashier_id != null ? '' : 'd-none'}}">
                            <div class="form-group">
                                <label class="required" for="cashier">{{ trans('cruds.generalLedger.fields.cashier') }} / {{ trans('cruds.generalLedger.fields.attendent') }}</label>
                                <select class="cashier_id form-control {{ $errors->has('cashier') ? 'is-invalid' : '' }}" name="cashier">
                                @foreach ($cashier as $key => $value)
                                    <option value="{{$key}}" {{$generalLedger->cashier_id == $key ? 'selected':''}}>{{$value}}</option>
                                @endforeach
                                </select>
                                @if($errors->has('cashier'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('cashier') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.generalLedger.fields.sub_category_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="amount">{{ trans('cruds.generalLedger.fields.amount') }}</label>
                                <input class="form-control {{ $errors->has('amount') ? 'is-invalid' : '' }}" type="number" step="any" name="amount"  value="{{ old('amount', $generalLedger->amount) }}" required>
                                @if($errors->has('amount'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('amount') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.generalLedger.fields.amount_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label for="detail">{{ trans('cruds.generalLedger.fields.detail') }}</label>
                                <input class="form-control {{ $errors->has('detail') ? 'is-invalid' : '' }}" type="text" name="detail"  value="{{ old('detail', $generalLedger->detail) }}">
                                @if($errors->has('detail'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('detail') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.generalLedger.fields.detail_helper') }}</span>
                            </div>
                        </div> 
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="form-group">
                                <button class="btn btn-primary" type="submit">
                                    {{ trans('global.save') }}
                                </button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>
@endsection
@section('scripts')
    <script>
        $(document).ready(function(){
            $('.sub_cat').on('change', function() {
              var id = $(this).val();
              if(id == '47' || id == '48' || id == '49'){
                  $(this).closest('.row').find('.cashier-block').removeClass('d-none');
                  var cashier = $(this).closest('.row').find('.cashier_id').empty();
                  if(id) {
                      $.ajax({
                          url: url + "/admin/fetch-cashier/"+id,
                          type: "GET",
                          dataType: "json",
                          success:function(data) {
                              cashier.append('<option value="">Please Select</option>');
                              $.each(data, function(key,value) {
                                  cashier.append('<option value="'+ key +'">'+ value +'</option>');
                              });

                          }
                      });
                  }
                }
              else{                
                $(this).closest('.row').find('.cashier-block').addClass('d-none');
              }
          });
        });
    </script>
@endsection
